diff --git a/applications/solvers/multiphase/settlingFoam/UEqn.H b/applications/solvers/multiphase/settlingFoam/UEqn.H
index 04e9194363d9ee4edc6aaa65e032fcebcaeddfca..390eeb05023cf76f8869339660f94ea4e15adb21 100644
--- a/applications/solvers/multiphase/settlingFoam/UEqn.H
+++ b/applications/solvers/multiphase/settlingFoam/UEqn.H
@@ -22,8 +22,7 @@
           ==
             fvc::reconstruct
             (
-                fvc::interpolate(rho)*(g & mesh.Sf())
-              - fvc::snGrad(p)*mesh.magSf()
+                (- ghf*fvc::snGrad(rho) - fvc::snGrad(pmh))*mesh.magSf()
             )
         );
     }
diff --git a/applications/solvers/multiphase/settlingFoam/createFields.H b/applications/solvers/multiphase/settlingFoam/createFields.H
index a085aebb37fc0c549b9f11d622a7f65a0c727b8e..6833c90ec9b8dda5d405c7832c3d336d95590224 100644
--- a/applications/solvers/multiphase/settlingFoam/createFields.H
+++ b/applications/solvers/multiphase/settlingFoam/createFields.H
@@ -1,9 +1,9 @@
-    Info<< "Reading field p\n" << endl;
-    volScalarField p
+    Info<< "Reading field pmh\n" << endl;
+    volScalarField pmh
     (
         IOobject
         (
-            "p",
+            "pmh",
             runTime.timeName(),
             mesh,
             IOobject::MUST_READ,
@@ -119,11 +119,6 @@
     #include "compressibleCreatePhi.H"
 
 
-    label pRefCell = 0;
-    scalar pRefValue = 0.0;
-    setRefCell(p, mesh.solutionDict().subDict("PISO"), pRefCell, pRefValue);
-
-
     Info<< "Calculating field mul\n" << endl;
     volScalarField mul
     (
@@ -346,3 +341,48 @@
         ),
         mut + mul
     );
+
+
+    Info<< "Calculating field (g.h)f\n" << endl;
+    volScalarField gh("gh", g & mesh.C());
+    surfaceScalarField ghf = surfaceScalarField("gh", g & mesh.Cf());
+
+    volScalarField p
+    (
+        IOobject
+        (
+            "p",
+            runTime.timeName(),
+            mesh,
+            IOobject::NO_READ,
+            IOobject::AUTO_WRITE
+        ),
+        pmh + rho*gh
+    );
+
+    label pmhRefCell = 0;
+    scalar pmhRefValue = 0.0;
+    setRefCell
+    (
+        pmh,
+        mesh.solutionDict().subDict("PISO"),
+        pmhRefCell,
+        pmhRefValue
+    );
+
+    scalar pRefValue = 0.0;
+
+    if (pmh.needReference())
+    {
+        pRefValue = readScalar
+        (
+            mesh.solutionDict().subDict("PISO").lookup("pRefValue")
+        );
+
+        p += dimensionedScalar
+        (
+            "p",
+            p.dimensions(),
+            pRefValue - getRefCellValue(p, pmhRefCell)
+        );
+    }
diff --git a/applications/solvers/multiphase/settlingFoam/pmhEqn.H b/applications/solvers/multiphase/settlingFoam/pmhEqn.H
new file mode 100644
index 0000000000000000000000000000000000000000..5a9b01a6f28802b06f566285fef230df5f7274c0
--- /dev/null
+++ b/applications/solvers/multiphase/settlingFoam/pmhEqn.H
@@ -0,0 +1,52 @@
+volScalarField rUA = 1.0/UEqn.A();
+
+surfaceScalarField rUAf
+(
+    "(rho*(1|A(U)))",
+    fvc::interpolate(rho)*fvc::interpolate(rUA)
+);
+
+U = rUA*UEqn.H();
+phi =
+    fvc::interpolate(rho)
+   *(
+       (fvc::interpolate(U) & mesh.Sf())
+     + fvc::ddtPhiCorr(rUA, rho, U, phi)
+    );
+
+surfaceScalarField phiU("phiU", phi);
+phi -= ghf*fvc::snGrad(rho)*rUAf*mesh.magSf();
+
+for(int nonOrth=0; nonOrth<=nNonOrthCorr; nonOrth++)
+{
+    fvScalarMatrix pmhEqn
+    (
+        fvm::laplacian(rUAf, pmh) == fvc::ddt(rho) + fvc::div(phi)
+    );
+
+    pmhEqn.setReference(pmhRefCell, pmhRefValue);
+    pmhEqn.solve();
+
+    if (nonOrth == nNonOrthCorr)
+    {
+        phi -= pmhEqn.flux();
+    }
+}
+
+p == pmh + rho*gh;
+
+if (pmh.needReference())
+{
+    p += dimensionedScalar
+    (
+        "p",
+        p.dimensions(),
+        pRefValue - getRefCellValue(p, pmhRefCell)
+    );
+}
+
+#include "rhoEqn.H"
+#include "compressibleContinuityErrs.H"
+
+U += rUA*fvc::reconstruct((phi - phiU)/rUAf);
+U.correctBoundaryConditions();
diff --git a/applications/solvers/multiphase/settlingFoam/settlingFoam.C b/applications/solvers/multiphase/settlingFoam/settlingFoam.C
index 942ed729bedc1f24eeffd66cba1bcf727b70fca0..006870828a25d4962a39b004df0ae779e7b957e1 100644
--- a/applications/solvers/multiphase/settlingFoam/settlingFoam.C
+++ b/applications/solvers/multiphase/settlingFoam/settlingFoam.C
@@ -64,23 +64,25 @@ int main(int argc, char *argv[])
 
         #include "rhoEqn.H"
 
-        #include "calcVdj.H"
+        for (int oCorr=0; oCorr<nOuterCorr; oCorr++)
+        {
+            #include "calcVdj.H"
 
-        #include "UEqn.H"
+            #include "UEqn.H"
 
-        #include "alphaEqn.H"
+            #include "alphaEqn.H"
 
-        #include "correctViscosity.H"
+            #include "correctViscosity.H"
 
+            // --- PISO loop
+            for (int corr=0; corr<nCorr; corr++)
+            {
+                #include "pmhEqn.H"
+            }
 
-        // --- PISO loop
-        for (int corr=0; corr<nCorr; corr++)
-        {
-            #include "pEqn.H"
+            #include "kEpsilon.H"
         }
 
-        #include "kEpsilon.H"
-
         runTime.write();
 
         Info<< "ExecutionTime = " << runTime.elapsedCpuTime() << " s"
diff --git a/src/OpenFOAM/fields/GeometricFields/GeometricField/GeometricField.H b/src/OpenFOAM/fields/GeometricFields/GeometricField/GeometricField.H
index 4e38804cc93a99852716a730c3f34b55819f6300..f9ac079b0fcf69735d14ff33a402bbe78fb68afa 100644
--- a/src/OpenFOAM/fields/GeometricFields/GeometricField/GeometricField.H
+++ b/src/OpenFOAM/fields/GeometricFields/GeometricField/GeometricField.H
@@ -345,12 +345,12 @@ public:
         );
 
         //- Construct as copy of tmp<GeometricField> deleting argument
-#       ifdef ConstructFromTmp
+        #ifdef ConstructFromTmp
         GeometricField
         (
             const tmp<GeometricField<Type, PatchField, GeoMesh> >&
         );
-#       endif
+        #endif
 
         //- Construct as copy resetting IO parameters
         GeometricField
@@ -367,13 +367,13 @@ public:
         );
 
         //- Construct as copy resetting name
-#       ifdef ConstructFromTmp
+        #ifdef ConstructFromTmp
         GeometricField
         (
             const word& newName,
             const tmp<GeometricField<Type, PatchField, GeoMesh> >&
         );
-#       endif
+        #endif
 
         //- Construct as copy resetting IO parameters and patch type
         GeometricField
@@ -392,9 +392,8 @@ public:
         );
 
 
-    // Destructor
-
-        virtual ~GeometricField();
+    //- Destructor
+    virtual ~GeometricField();
 
 
     // Member Functions
diff --git a/src/OpenFOAM/primitives/Scalar/Scalar.H b/src/OpenFOAM/primitives/Scalar/Scalar.H
index 4c818be7c41a4a21c8e9ef404f529174fb46f4ce..f6904dce98e972d974700d5dec5b56d1ae2b661c 100644
--- a/src/OpenFOAM/primitives/Scalar/Scalar.H
+++ b/src/OpenFOAM/primitives/Scalar/Scalar.H
@@ -2,7 +2,7 @@
   =========                 |
   \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
    \\    /   O peration     |
-    \\  /    A nd           | Copyright (C) 1991-2009 OpenCFD Ltd.
+    \\  /    A nd           | Copyright (C) 1991-2010 OpenCFD Ltd.
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
 License
@@ -72,11 +72,17 @@ public:
 
     // Member Functions
 
-        //- Conversion to a Scalar
+        //- Access to the Scalar value
         operator Scalar() const
         {
             return p_;
         }
+
+        //- Access to the Scalar value
+        operator Scalar&()
+        {
+            return p_;
+        }
 };
 
 
diff --git a/src/OpenFOAM/primitives/bools/bool/bool.H b/src/OpenFOAM/primitives/bools/bool/bool.H
index 78d8f58f93a3af7e325def50264ffae2d2cf8b49..999355f679521bd88544f452e0871209a16d2c82 100644
--- a/src/OpenFOAM/primitives/bools/bool/bool.H
+++ b/src/OpenFOAM/primitives/bools/bool/bool.H
@@ -2,7 +2,7 @@
   =========                 |
   \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
    \\    /   O peration     |
-    \\  /    A nd           | Copyright (C) 1991-2009 OpenCFD Ltd.
+    \\  /    A nd           | Copyright (C) 1991-2010 OpenCFD Ltd.
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
 License
@@ -81,6 +81,7 @@ public:
             nComponents = 1  //!< Number of components in bool is 1
         };
 
+
     // Static data members
 
         static const char* const typeName;
@@ -88,18 +89,26 @@ public:
         static const bool zero;
         static const bool one;
 
+
     // Constructors
 
         //- Construct from Istream
         pTraits(Istream&);
 
+
     // Member Functions
 
-        //- Conversion to a bool
+        //- Access to the bool value
         operator bool() const
         {
             return p_;
         }
+
+        //- Access to the bool value
+        operator bool&()
+        {
+            return p_;
+        }
 };
 
 
diff --git a/src/OpenFOAM/primitives/ints/label/label.H b/src/OpenFOAM/primitives/ints/label/label.H
index c81d8232418ccb0f327a05e95665a1d5c7c90bfa..81bf55e4b1eeebfb24e50ce64a7025d7252c6e7e 100644
--- a/src/OpenFOAM/primitives/ints/label/label.H
+++ b/src/OpenFOAM/primitives/ints/label/label.H
@@ -2,7 +2,7 @@
   =========                 |
   \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
    \\    /   O peration     |
-    \\  /    A nd           | Copyright (C) 1991-2009 OpenCFD Ltd.
+    \\  /    A nd           | Copyright (C) 1991-2010 OpenCFD Ltd.
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
 License
@@ -153,6 +153,7 @@ public:
             nComponents = 1  //!< Number of components in label is 1
         };
 
+
     // Static data members
 
         static const char* const typeName;
@@ -162,18 +163,26 @@ public:
         static const label min;
         static const label max;
 
+
     // Constructors
 
         //- Construct from Istream
         pTraits(Istream&);
 
+
     // Member Functions
 
-        //- Conversion to a label
+        //- Access to the label value
         operator label() const
         {
             return p_;
         }
+
+        //- Access to the label value
+        operator label&()
+        {
+            return p_;
+        }
 };
 
 
diff --git a/src/OpenFOAM/primitives/ints/uLabel/uLabel.H b/src/OpenFOAM/primitives/ints/uLabel/uLabel.H
index 23115fe99f3c453072b864db31255514ddedd587..2ab4b5b7c9357187be06d51da1777942313ea76f 100644
--- a/src/OpenFOAM/primitives/ints/uLabel/uLabel.H
+++ b/src/OpenFOAM/primitives/ints/uLabel/uLabel.H
@@ -2,7 +2,7 @@
   =========                 |
   \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
    \\    /   O peration     |
-    \\  /    A nd           | Copyright (C) 1991-2009 OpenCFD Ltd.
+    \\  /    A nd           | Copyright (C) 1991-2010 OpenCFD Ltd.
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
 License
@@ -137,6 +137,7 @@ public:
             nComponents = 1  //!< Number of components in uLabel is 1
         };
 
+
     // Static data members
 
         static const char* const typeName;
@@ -146,6 +147,7 @@ public:
         static const uLabel max;
         static const uLabel min;
 
+
     // Constructors
 
         //- Construct from Istream
@@ -154,11 +156,17 @@ public:
 
     // Member Functions
 
-        //- Conversion to a uLabel
+        //- Access to the uLabel value
         operator uLabel() const
         {
             return p_;
         }
+
+        //- Access to the uLabel value
+        operator uLabel&()
+        {
+            return p_;
+        }
 };
 
 
diff --git a/src/OpenFOAM/primitives/pTraits/pTraits.H b/src/OpenFOAM/primitives/pTraits/pTraits.H
index 98a3df7ec9117394ab3882c303f14186da8a2ae1..1712f2746da828833cd9c1aa1a0ccdcb3f902e07 100644
--- a/src/OpenFOAM/primitives/pTraits/pTraits.H
+++ b/src/OpenFOAM/primitives/pTraits/pTraits.H
@@ -2,7 +2,7 @@
   =========                 |
   \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
    \\    /   O peration     |
-    \\  /    A nd           | Copyright (C) 1991-2009 OpenCFD Ltd.
+    \\  /    A nd           | Copyright (C) 1991-2010 OpenCFD Ltd.
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
 License
@@ -54,15 +54,30 @@ class pTraits
 
 public:
 
-    pTraits(const PrimitiveType& p)
-    :
-        PrimitiveType(p)
-    {}
+    // Constructors
 
-    pTraits(Istream& is)
-    :
-        PrimitiveType(is)
-    {}
+        pTraits(const PrimitiveType& p)
+        :
+            PrimitiveType(p)
+        {}
+
+        pTraits(Istream& is)
+        :
+            PrimitiveType(is)
+        {}
+
+
+    // Member operators
+
+        operator PrimitiveType() const
+        {
+            return *this;
+        }
+
+        operator PrimitiveType&()
+        {
+            return *this;
+        }
 };
 
 
diff --git a/src/finiteVolume/fields/fvPatchFields/derived/timeVaryingMappedFixedValue/AverageIOField.C b/src/finiteVolume/fields/fvPatchFields/derived/timeVaryingMappedFixedValue/AverageIOField.C
index 1450290f7453fa980e5548393b4af479daef4d6b..2f079100a59f6873a0efbb063e23c65f78faea9f 100644
--- a/src/finiteVolume/fields/fvPatchFields/derived/timeVaryingMappedFixedValue/AverageIOField.C
+++ b/src/finiteVolume/fields/fvPatchFields/derived/timeVaryingMappedFixedValue/AverageIOField.C
@@ -2,7 +2,7 @@
   =========                 |
   \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
    \\    /   O peration     |
-    \\  /    A nd           | Copyright (C) 1991-2009 OpenCFD Ltd.
+    \\  /    A nd           | Copyright (C) 1991-2010 OpenCFD Ltd.
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
 License
@@ -26,42 +26,37 @@ License
 
 #include "AverageIOField.H"
 
-// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
-
-namespace Foam
-{
-
 // * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //
 
 template<class Type>
-AverageIOField<Type>::AverageIOField
+Foam::AverageIOField<Type>::AverageIOField
 (
     const IOobject& io
 )
 :
-    regIOobject(io),
-    pTraits<Type>(readStream(typeName)),
-    Field<Type>(readStream(typeName))
+    regIOobject(io)
 {
+    readStream(typeName) >> average_;
+    readStream(typeName) >> static_cast<Field<Type>&>(*this);
     close();
 }
 
 
 template<class Type>
-AverageIOField<Type>::AverageIOField
+Foam::AverageIOField<Type>::AverageIOField
 (
     const IOobject& io,
     const label size
 )
 :
     regIOobject(io),
-    pTraits<Type>(pTraits<Type>::zero),
-    Field<Type>(size)
+    Field<Type>(size),
+    average_(0)
 {}
 
 
 template<class Type>
-AverageIOField<Type>::AverageIOField
+Foam::AverageIOField<Type>::AverageIOField
 (
     const IOobject& io,
     const Type& average,
@@ -69,21 +64,28 @@ AverageIOField<Type>::AverageIOField
 )
 :
     regIOobject(io),
-    pTraits<Type>(average),
-    Field<Type>(f)
+    Field<Type>(f),
+    average_(average)
 {
     if (io.readOpt() == IOobject::READ_IF_PRESENT && headerOk())
     {
         readStream(typeName)
-            >> static_cast<Type&>(*this)
+            >> average_
             >> static_cast<Field<Type>&>(*this);
         close();
     }
 }
 
 
-// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
+template<class Type>
+bool Foam::AverageIOField<Type>::writeData(Ostream& os) const
+{
+    os  << average_
+        << token::NL
+        << static_cast<const Field<Type>&>(*this);
+
+    return os.good();
+}
 
-} // End namespace Foam
 
 // ************************************************************************* //
diff --git a/src/finiteVolume/fields/fvPatchFields/derived/timeVaryingMappedFixedValue/AverageIOField.H b/src/finiteVolume/fields/fvPatchFields/derived/timeVaryingMappedFixedValue/AverageIOField.H
index 4217dcbd1a36ee418ef489c9ff4342bf46efb6ea..25634ab109dc503220d9ce4ee8cc71d9d73f92f8 100644
--- a/src/finiteVolume/fields/fvPatchFields/derived/timeVaryingMappedFixedValue/AverageIOField.H
+++ b/src/finiteVolume/fields/fvPatchFields/derived/timeVaryingMappedFixedValue/AverageIOField.H
@@ -2,7 +2,7 @@
   =========                 |
   \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
    \\    /   O peration     |
-    \\  /    A nd           | Copyright (C) 1991-2009 OpenCFD Ltd.
+    \\  /    A nd           | Copyright (C) 1991-2010 OpenCFD Ltd.
      \\/     M anipulation  |
 -------------------------------------------------------------------------------
 License
@@ -45,16 +45,20 @@ namespace Foam
 {
 
 /*---------------------------------------------------------------------------*\
-                           Class AverageIOField Declaration
+                        Class AverageIOField Declaration
 \*---------------------------------------------------------------------------*/
 
 template<class Type>
 class AverageIOField
 :
     public regIOobject,
-    public pTraits<Type>,
     public Field<Type>
 {
+    // Private data
+
+        //- The average of the field
+        Type average_;
+
 
 public:
 
@@ -87,19 +91,17 @@ public:
 
     // Member functions
 
-        const pTraits<Type>& average() const
+        const Type& average() const
         {
-            return static_cast<const pTraits<Type>&>(*this);
+            return average_;
         }
 
-        bool writeData(Ostream& os) const
+        Type& average()
         {
-            os  << static_cast<const Type&>(*this)
-                << token::NL
-                << static_cast<const Field<Type>&>(*this);
-
-            return os.good();
+            return average_;
         }
+
+        bool writeData(Ostream& os) const;
 };
 
 
diff --git a/src/finiteVolume/fields/fvPatchFields/derived/timeVaryingMappedFixedValue/AverageIOFields.C b/src/finiteVolume/fields/fvPatchFields/derived/timeVaryingMappedFixedValue/AverageIOFields.C
index e39cd28d904d3d8d5bd6d568b5b3b7260417d52e..066b741abe653ba88767e079acb7fffc3b9d144b 100644
--- a/src/finiteVolume/fields/fvPatchFields/derived/timeVaryingMappedFixedValue/AverageIOFields.C
+++ b/src/finiteVolume/fields/fvPatchFields/derived/timeVaryingMappedFixedValue/AverageIOFields.C
@@ -22,6 +22,8 @@ License
     along with OpenFOAM; if not, write to the Free Software Foundation,
     Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
+Description
+
 \*---------------------------------------------------------------------------*/
 
 #include "AverageIOField.H"
diff --git a/src/finiteVolume/fields/fvPatchFields/derived/timeVaryingMappedFixedValue/timeVaryingMappedFixedValueFvPatchField.C b/src/finiteVolume/fields/fvPatchFields/derived/timeVaryingMappedFixedValue/timeVaryingMappedFixedValueFvPatchField.C
index b1afef7b8837722e95ea616eafcfaf678e4cb12e..9ce0597ff270971b24b67864ba3c8c81418eb1ee 100644
--- a/src/finiteVolume/fields/fvPatchFields/derived/timeVaryingMappedFixedValue/timeVaryingMappedFixedValueFvPatchField.C
+++ b/src/finiteVolume/fields/fvPatchFields/derived/timeVaryingMappedFixedValue/timeVaryingMappedFixedValueFvPatchField.C
@@ -49,6 +49,7 @@ timeVaryingMappedFixedValueFvPatchField
 )
 :
     fixedValueFvPatchField<Type>(p, iF),
+    fieldTableName_(iF.name()),
     setAverage_(false),
     referenceCS_(NULL),
     nearestVertex_(0),
@@ -80,6 +81,7 @@ timeVaryingMappedFixedValueFvPatchField
 )
 :
     fixedValueFvPatchField<Type>(ptf, p, iF, mapper),
+    fieldTableName_(ptf.fieldTableName_),
     setAverage_(ptf.setAverage_),
     referenceCS_(NULL),
     nearestVertex_(0),
@@ -110,6 +112,7 @@ timeVaryingMappedFixedValueFvPatchField
 )
 :
     fixedValueFvPatchField<Type>(p, iF),
+    fieldTableName_(iF.name()),
     setAverage_(readBool(dict.lookup("setAverage"))),
     referenceCS_(NULL),
     nearestVertex_(0),
@@ -128,6 +131,11 @@ timeVaryingMappedFixedValueFvPatchField
             << endl;
     }
 
+    if (dict.found("fieldTableName"))
+    {
+        dict.lookup("fieldTableName") >> fieldTableName_;
+    }
+
     if (dict.found("value"))
     {
         fvPatchField<Type>::operator==(Field<Type>("value", dict, p.size()));
@@ -147,6 +155,7 @@ timeVaryingMappedFixedValueFvPatchField
 )
 :
     fixedValueFvPatchField<Type>(ptf),
+    fieldTableName_(ptf.fieldTableName_),
     setAverage_(ptf.setAverage_),
     referenceCS_(ptf.referenceCS_),
     nearestVertex_(ptf.nearestVertex_),
@@ -177,6 +186,7 @@ timeVaryingMappedFixedValueFvPatchField
 )
 :
     fixedValueFvPatchField<Type>(ptf, iF),
+    fieldTableName_(ptf.fieldTableName_),
     setAverage_(ptf.setAverage_),
     referenceCS_(ptf.referenceCS_),
     nearestVertex_(ptf.nearestVertex_),
@@ -271,8 +281,8 @@ void timeVaryingMappedFixedValueFvPatchField<Type>::readSamplePoints()
             << "Need at least three non-colinear samplePoints"
             << " to be able to interpolate."
             << "\n    on patch " << this->patch().name()
-            << " of field " << this->dimensionedInternalField().name()
-            << " in file " << this->dimensionedInternalField().objectPath()
+            << " of points " << samplePoints.name()
+            << " in file " << samplePoints.objectPath()
             << exit(FatalError);
     }
 
@@ -332,8 +342,8 @@ void timeVaryingMappedFixedValueFvPatchField<Type>::readSamplePoints()
         )   << "Cannot find points that make valid normal." << nl
             << "Need at least three sample points which are not in a line."
             << "\n    on patch " << this->patch().name()
-            << " of field " << this->dimensionedInternalField().name()
-            << " in file " << this->dimensionedInternalField().objectPath()
+            << " of points " << samplePoints.name()
+            << " in file " << samplePoints.objectPath()
             << exit(FatalError);
     }
 
@@ -474,8 +484,7 @@ void timeVaryingMappedFixedValueFvPatchField<Type>::findTime
             << "In directory "
             <<  this->db().time().constant()/"boundaryData"/this->patch().name()
             << "\n    on patch " << this->patch().name()
-            << " of field " << this->dimensionedInternalField().name()
-            << " in file " << this->dimensionedInternalField().objectPath()
+            << " of field " << fieldTableName_
             << exit(FatalError);
     }
 
@@ -563,7 +572,7 @@ void timeVaryingMappedFixedValueFvPatchField<Type>::checkTable()
             (
                 IOobject
                 (
-                    this->dimensionedInternalField().name(),
+                    fieldTableName_,
                     this->db().time().constant(),
                     "boundaryData"
                    /this->patch().name()
@@ -608,7 +617,7 @@ void timeVaryingMappedFixedValueFvPatchField<Type>::checkTable()
             (
                 IOobject
                 (
-                    this->dimensionedInternalField().name(),
+                    fieldTableName_,
                     this->db().time().constant(),
                     "boundaryData"
                    /this->patch().name()
@@ -771,6 +780,12 @@ void timeVaryingMappedFixedValueFvPatchField<Type>::write(Ostream& os) const
 {
     fvPatchField<Type>::write(os);
     os.writeKeyword("setAverage") << setAverage_ << token::END_STATEMENT << nl;
+
+    if (fieldTableName_ != this->dimensionedInternalField().name())
+    {
+        os.writeKeyword("fieldTableName") << fieldTableName_ << token::END_STATEMENT << nl;
+    }
+
     this->writeEntry("value", os);
 }
 
diff --git a/src/finiteVolume/fields/fvPatchFields/derived/timeVaryingMappedFixedValue/timeVaryingMappedFixedValueFvPatchField.H b/src/finiteVolume/fields/fvPatchFields/derived/timeVaryingMappedFixedValue/timeVaryingMappedFixedValueFvPatchField.H
index 31b88ae03aa11537c31f93f2d78451d0549f3593..a310c8f4dc721924b84233ca1bc78a6ea3b8776d 100644
--- a/src/finiteVolume/fields/fvPatchFields/derived/timeVaryingMappedFixedValue/timeVaryingMappedFixedValueFvPatchField.H
+++ b/src/finiteVolume/fields/fvPatchFields/derived/timeVaryingMappedFixedValue/timeVaryingMappedFixedValueFvPatchField.H
@@ -57,6 +57,9 @@ class timeVaryingMappedFixedValueFvPatchField
 {
     // Private data
 
+        //- Name of the field data table, defaults to the name of the field
+        word fieldTableName_;
+
         //- If true adjust the mapped field to maintain average value
         bool setAverage_;
 
diff --git a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/0/K b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/0/K
index ea49df4585987cef0b06a7e8c526e9b629b3d4ba..4068676987cd2dd76f0d037797f8ff5c731ba2eb 100644
--- a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/0/K
+++ b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/0/K
@@ -1,7 +1,7 @@
 /*--------------------------------*- C++ -*----------------------------------*\
 | =========                 |                                                 |
 | \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
-|  \\    /   O peration     | Version:  dev                                   |
+|  \\    /   O peration     | Version:  1.6                                   |
 |   \\  /    A nd           | Web:      http://www.OpenFOAM.org               |
 |    \\/     M anipulation  |                                                 |
 \*---------------------------------------------------------------------------*/
diff --git a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/0/T b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/0/T
index 8788a0bc787fbfd8f084fe56c7ef4b1f3f8662d3..c6ae16042a23970bf06cb47a4d916c97d04ececb 100644
--- a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/0/T
+++ b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/0/T
@@ -1,7 +1,7 @@
 /*--------------------------------*- C++ -*----------------------------------*\
 | =========                 |                                                 |
 | \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
-|  \\    /   O peration     | Version:  dev                                   |
+|  \\    /   O peration     | Version:  1.6                                   |
 |   \\  /    A nd           | Web:      http://www.OpenFOAM.org               |
 |    \\/     M anipulation  |                                                 |
 \*---------------------------------------------------------------------------*/
diff --git a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/0/U b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/0/U
index 1b349bf9acf5bf2398b3daa7209d507c846c5d20..42ab6a0a093e32a475a47cec7682dc47d2b91093 100644
--- a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/0/U
+++ b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/0/U
@@ -1,7 +1,7 @@
 /*--------------------------------*- C++ -*----------------------------------*\
 | =========                 |                                                 |
 | \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
-|  \\    /   O peration     | Version:  dev                                   |
+|  \\    /   O peration     | Version:  1.6                                   |
 |   \\  /    A nd           | Web:      http://www.OpenFOAM.org               |
 |    \\/     M anipulation  |                                                 |
 \*---------------------------------------------------------------------------*/
diff --git a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/0/cp b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/0/cp
index 848efdc53d80c8cfbe64015c14ba5a851e0dbf5b..84aab72ae1cdbe89a2ad06c7c6b3fafa51c33b87 100644
--- a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/0/cp
+++ b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/0/cp
@@ -1,7 +1,7 @@
 /*--------------------------------*- C++ -*----------------------------------*\
 | =========                 |                                                 |
 | \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
-|  \\    /   O peration     | Version:  dev                                   |
+|  \\    /   O peration     | Version:  1.6                                   |
 |   \\  /    A nd           | Web:      http://www.OpenFOAM.org               |
 |    \\/     M anipulation  |                                                 |
 \*---------------------------------------------------------------------------*/
diff --git a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/0/epsilon b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/0/epsilon
index 6d6c661d937489aaf24e4a8ac205359613c13f85..f5dfd4cc5503b9ee3ab9219dd0da16d529425faa 100644
--- a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/0/epsilon
+++ b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/0/epsilon
@@ -1,7 +1,7 @@
 /*--------------------------------*- C++ -*----------------------------------*\
 | =========                 |                                                 |
 | \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
-|  \\    /   O peration     | Version:  dev                                   |
+|  \\    /   O peration     | Version:  1.6                                   |
 |   \\  /    A nd           | Web:      www.OpenFOAM.org                      |
 |    \\/     M anipulation  |                                                 |
 \*---------------------------------------------------------------------------*/
diff --git a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/0/k b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/0/k
index b657a9bf05a8fd42d005937f5d0395a003f762ab..f8bfda5d8e75aa4b5c37283bdbcbb190fa5a6898 100644
--- a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/0/k
+++ b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/0/k
@@ -1,7 +1,7 @@
 /*--------------------------------*- C++ -*----------------------------------*\
 | =========                 |                                                 |
 | \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
-|  \\    /   O peration     | Version:  dev                                   |
+|  \\    /   O peration     | Version:  1.6                                   |
 |   \\  /    A nd           | Web:      www.OpenFOAM.org                      |
 |    \\/     M anipulation  |                                                 |
 \*---------------------------------------------------------------------------*/
diff --git a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/0/p b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/0/p
index 31a16ae78c73b200b714fee5ba352be1243ef849..0233591ba356bbb9965aa9b06fe11aac419d1c5a 100644
--- a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/0/p
+++ b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/0/p
@@ -1,7 +1,7 @@
 /*--------------------------------*- C++ -*----------------------------------*\
 | =========                 |                                                 |
 | \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
-|  \\    /   O peration     | Version:  dev                                   |
+|  \\    /   O peration     | Version:  1.6                                   |
 |   \\  /    A nd           | Web:      http://www.OpenFOAM.org               |
 |    \\/     M anipulation  |                                                 |
 \*---------------------------------------------------------------------------*/
diff --git a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/0/rho b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/0/rho
index 901d2457a5169375edc94df6cace0f5b0bbee46f..e8c31261f17caace5f88ee78dd69ce48770986ce 100644
--- a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/0/rho
+++ b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/0/rho
@@ -1,7 +1,7 @@
 /*--------------------------------*- C++ -*----------------------------------*\
 | =========                 |                                                 |
 | \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
-|  \\    /   O peration     | Version:  dev                                   |
+|  \\    /   O peration     | Version:  1.6                                   |
 |   \\  /    A nd           | Web:      http://www.OpenFOAM.org               |
 |    \\/     M anipulation  |                                                 |
 \*---------------------------------------------------------------------------*/
diff --git a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/constant/bottomAir/RASProperties b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/constant/bottomAir/RASProperties
index 29aa27e2378121b1620e293c24e384922b046665..0d135f28e9f77d83787cf6240d8ebc961aa3be47 100644
--- a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/constant/bottomAir/RASProperties
+++ b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/constant/bottomAir/RASProperties
@@ -1,7 +1,7 @@
 /*--------------------------------*- C++ -*----------------------------------*\
 | =========                 |                                                 |
 | \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
-|  \\    /   O peration     | Version:  dev                                   |
+|  \\    /   O peration     | Version:  1.6                                   |
 |   \\  /    A nd           | Web:      http://www.OpenFOAM.org               |
 |    \\/     M anipulation  |                                                 |
 \*---------------------------------------------------------------------------*/
diff --git a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/constant/bottomAir/g b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/constant/bottomAir/g
index 6f32e338356b14a2d7ff55d2d3f7e948dd1e8479..af6459f97c419fbe1c43c5abd30c3fb29310e992 100644
--- a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/constant/bottomAir/g
+++ b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/constant/bottomAir/g
@@ -1,7 +1,7 @@
 /*--------------------------------*- C++ -*----------------------------------*\
 | =========                 |                                                 |
 | \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
-|  \\    /   O peration     | Version:  dev                                   |
+|  \\    /   O peration     | Version:  1.6                                   |
 |   \\  /    A nd           | Web:      www.OpenFOAM.org                      |
 |    \\/     M anipulation  |                                                 |
 \*---------------------------------------------------------------------------*/
diff --git a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/constant/bottomAir/thermophysicalProperties b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/constant/bottomAir/thermophysicalProperties
index af8ff6f5eb4a073a1d890d8c385db0a1cd3fdedb..c2d48ee2b07a5e07c946f1f9b253e0f5da364b75 100644
--- a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/constant/bottomAir/thermophysicalProperties
+++ b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/constant/bottomAir/thermophysicalProperties
@@ -1,7 +1,7 @@
 /*--------------------------------*- C++ -*----------------------------------*\
 | =========                 |                                                 |
 | \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
-|  \\    /   O peration     | Version:  dev                                   |
+|  \\    /   O peration     | Version:  1.6                                   |
 |   \\  /    A nd           | Web:      http://www.OpenFOAM.org               |
 |    \\/     M anipulation  |                                                 |
 \*---------------------------------------------------------------------------*/
diff --git a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/constant/bottomAir/turbulenceProperties b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/constant/bottomAir/turbulenceProperties
index e009ce86dad347dba559dac50a0c90718781edcb..9edb2bbd94bab3c47940647b1052ed861e056d6a 100644
--- a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/constant/bottomAir/turbulenceProperties
+++ b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/constant/bottomAir/turbulenceProperties
@@ -1,7 +1,7 @@
 /*--------------------------------*- C++ -*----------------------------------*\
 | =========                 |                                                 |
 | \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
-|  \\    /   O peration     | Version:  dev                                   |
+|  \\    /   O peration     | Version:  1.6                                   |
 |   \\  /    A nd           | Web:      http://www.OpenFOAM.org               |
 |    \\/     M anipulation  |                                                 |
 \*---------------------------------------------------------------------------*/
diff --git a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/constant/polyMesh/blockMeshDict b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/constant/polyMesh/blockMeshDict
index bd6aac3b71d0e93abe3c2c533b3699924902af17..06d8984cac79bcf4f38f35fa074db015f33fe978 100644
--- a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/constant/polyMesh/blockMeshDict
+++ b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/constant/polyMesh/blockMeshDict
@@ -1,7 +1,7 @@
 /*--------------------------------*- C++ -*----------------------------------*\
 | =========                 |                                                 |
 | \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
-|  \\    /   O peration     | Version:  dev                                   |
+|  \\    /   O peration     | Version:  1.6                                   |
 |   \\  /    A nd           | Web:      http://www.OpenFOAM.org               |
 |    \\/     M anipulation  |                                                 |
 \*---------------------------------------------------------------------------*/
diff --git a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/constant/regionProperties b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/constant/regionProperties
index 67629a878b29a468488555018ad2f66da330ffbe..2ba326a49be2af1c429e09e3b1e00e659ba71ee2 100644
--- a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/constant/regionProperties
+++ b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/constant/regionProperties
@@ -1,7 +1,7 @@
 /*--------------------------------*- C++ -*----------------------------------*\
 | =========                 |                                                 |
 | \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
-|  \\    /   O peration     | Version:  dev                                   |
+|  \\    /   O peration     | Version:  1.6                                   |
 |   \\  /    A nd           | Web:      www.OpenFOAM.org                      |
 |    \\/     M anipulation  |                                                 |
 \*---------------------------------------------------------------------------*/
diff --git a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/bottomAir/changeDictionaryDict b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/bottomAir/changeDictionaryDict
index db3cf3761e711f0190786578d43389b4fc4c4ed2..b9a8773586c82ac5d800e20139fde5154662b03a 100644
--- a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/bottomAir/changeDictionaryDict
+++ b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/bottomAir/changeDictionaryDict
@@ -1,7 +1,7 @@
 /*--------------------------------*- C++ -*----------------------------------*\
 | =========                 |                                                 |
 | \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
-|  \\    /   O peration     | Version:  dev                                   |
+|  \\    /   O peration     | Version:  1.6                                   |
 |   \\  /    A nd           | Web:      http://www.OpenFOAM.org               |
 |    \\/     M anipulation  |                                                 |
 \*---------------------------------------------------------------------------*/
diff --git a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/bottomAir/fvSchemes b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/bottomAir/fvSchemes
index 33f61814eb8a25c4e76871ec9a335355b7d4d601..cedcc3c61167fc381f40b263c8743d9cc76629c6 100644
--- a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/bottomAir/fvSchemes
+++ b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/bottomAir/fvSchemes
@@ -1,7 +1,7 @@
 /*--------------------------------*- C++ -*----------------------------------*\
 | =========                 |                                                 |
 | \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
-|  \\    /   O peration     | Version:  dev                                   |
+|  \\    /   O peration     | Version:  1.6                                   |
 |   \\  /    A nd           | Web:      http://www.OpenFOAM.org               |
 |    \\/     M anipulation  |                                                 |
 \*---------------------------------------------------------------------------*/
diff --git a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/bottomAir/fvSolution b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/bottomAir/fvSolution
index 742f7015a5f3f5d5fcd93da6d329c520fe418008..16947842afa6f8a069354291de55d8810a5c1d5c 100644
--- a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/bottomAir/fvSolution
+++ b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/bottomAir/fvSolution
@@ -1,7 +1,7 @@
 /*--------------------------------*- C++ -*----------------------------------*\
 | =========                 |                                                 |
 | \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
-|  \\    /   O peration     | Version:  dev                                   |
+|  \\    /   O peration     | Version:  1.6                                   |
 |   \\  /    A nd           | Web:      http://www.OpenFOAM.org               |
 |    \\/     M anipulation  |                                                 |
 \*---------------------------------------------------------------------------*/
diff --git a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/controlDict b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/controlDict
index 60ea53c7841ec80c5c486a16acfc03af339927f8..3e22a4695d20b7d82e9aef3ddfa178adecf6eca6 100644
--- a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/controlDict
+++ b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/controlDict
@@ -1,7 +1,7 @@
 /*--------------------------------*- C++ -*----------------------------------*\
 | =========                 |                                                 |
 | \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
-|  \\    /   O peration     | Version:  dev                                  |
+|  \\    /   O peration     | Version:  1.6                                  |
 |   \\  /    A nd           | Web:      www.OpenFOAM.org                      |
 |    \\/     M anipulation  |                                                 |
 \*---------------------------------------------------------------------------*/
diff --git a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/fvSchemes b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/fvSchemes
index 83b10f8ae8ba3a1eba15ff22d999442e4bf7acc7..7662a20c90a6cd9bdfe1b69c7ce6a893baee27e0 100644
--- a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/fvSchemes
+++ b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/fvSchemes
@@ -1,7 +1,7 @@
 /*--------------------------------*- C++ -*----------------------------------*\
 | =========                 |                                                 |
 | \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
-|  \\    /   O peration     | Version:  dev                                  |
+|  \\    /   O peration     | Version:  1.6                                  |
 |   \\  /    A nd           | Web:      http://www.OpenFOAM.org               |
 |    \\/     M anipulation  |                                                 |
 \*---------------------------------------------------------------------------*/
diff --git a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/fvSolution b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/fvSolution
index 568b5d9529db4de4c3fab794047ee5694f2be431..fd0e7cced2f2fa02d008a6052d4ac1060e3af1dc 100644
--- a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/fvSolution
+++ b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/fvSolution
@@ -1,7 +1,7 @@
 /*--------------------------------*- C++ -*----------------------------------*\
 | =========                 |                                                 |
 | \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
-|  \\    /   O peration     | Version:  dev                                   |
+|  \\    /   O peration     | Version:  1.6                                   |
 |   \\  /    A nd           | Web:      http://www.OpenFOAM.org               |
 |    \\/     M anipulation  |                                                 |
 \*---------------------------------------------------------------------------*/
diff --git a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/heater/changeDictionaryDict b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/heater/changeDictionaryDict
index dba9b78979556b04b26a2e296a14f7b89f306175..b2b1284ef3acd8b67e074a7fb7f6564cfa231b13 100644
--- a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/heater/changeDictionaryDict
+++ b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/heater/changeDictionaryDict
@@ -1,7 +1,7 @@
 /*--------------------------------*- C++ -*----------------------------------*\
 | =========                 |                                                 |
 | \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
-|  \\    /   O peration     | Version:  dev                                   |
+|  \\    /   O peration     | Version:  1.6                                   |
 |   \\  /    A nd           | Web:      http://www.OpenFOAM.org               |
 |    \\/     M anipulation  |                                                 |
 \*---------------------------------------------------------------------------*/
diff --git a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/heater/fvSchemes b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/heater/fvSchemes
index 8dc070f0eb0e09995c69cd12d99db88f1a80969d..74053b0ab3ded29a9bb6536d918e55e092273405 100644
--- a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/heater/fvSchemes
+++ b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/heater/fvSchemes
@@ -1,7 +1,7 @@
 /*--------------------------------*- C++ -*----------------------------------*\
 | =========                 |                                                 |
 | \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
-|  \\    /   O peration     | Version:  dev                                   |
+|  \\    /   O peration     | Version:  1.6                                   |
 |   \\  /    A nd           | Web:      http://www.OpenFOAM.org               |
 |    \\/     M anipulation  |                                                 |
 \*---------------------------------------------------------------------------*/
diff --git a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/heater/fvSolution b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/heater/fvSolution
index 0396116914478adfd7b2dd998fc93d22ea44e101..19370a0e39c4b42a7a58941a05170e9a33a37b4f 100644
--- a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/heater/fvSolution
+++ b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/heater/fvSolution
@@ -1,7 +1,7 @@
 /*--------------------------------*- C++ -*----------------------------------*\
 | =========                 |                                                 |
 | \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
-|  \\    /   O peration     | Version:  dev                                   |
+|  \\    /   O peration     | Version:  1.6                                   |
 |   \\  /    A nd           | Web:      http://www.OpenFOAM.org               |
 |    \\/     M anipulation  |                                                 |
 \*---------------------------------------------------------------------------*/
diff --git a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/leftSolid/changeDictionaryDict b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/leftSolid/changeDictionaryDict
index 6b4ffab625f004ca71b0409b62a7c81802d06695..05d3011024a3585fd845a854e340007df876be93 100644
--- a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/leftSolid/changeDictionaryDict
+++ b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/leftSolid/changeDictionaryDict
@@ -1,7 +1,7 @@
 /*--------------------------------*- C++ -*----------------------------------*\
 | =========                 |                                                 |
 | \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
-|  \\    /   O peration     | Version:  dev                                   |
+|  \\    /   O peration     | Version:  1.6                                   |
 |   \\  /    A nd           | Web:      http://www.OpenFOAM.org               |
 |    \\/     M anipulation  |                                                 |
 \*---------------------------------------------------------------------------*/
diff --git a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/leftSolid/fvSchemes b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/leftSolid/fvSchemes
index 8dc070f0eb0e09995c69cd12d99db88f1a80969d..74053b0ab3ded29a9bb6536d918e55e092273405 100644
--- a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/leftSolid/fvSchemes
+++ b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/leftSolid/fvSchemes
@@ -1,7 +1,7 @@
 /*--------------------------------*- C++ -*----------------------------------*\
 | =========                 |                                                 |
 | \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
-|  \\    /   O peration     | Version:  dev                                   |
+|  \\    /   O peration     | Version:  1.6                                   |
 |   \\  /    A nd           | Web:      http://www.OpenFOAM.org               |
 |    \\/     M anipulation  |                                                 |
 \*---------------------------------------------------------------------------*/
diff --git a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/leftSolid/fvSolution b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/leftSolid/fvSolution
index 0396116914478adfd7b2dd998fc93d22ea44e101..19370a0e39c4b42a7a58941a05170e9a33a37b4f 100644
--- a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/leftSolid/fvSolution
+++ b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/leftSolid/fvSolution
@@ -1,7 +1,7 @@
 /*--------------------------------*- C++ -*----------------------------------*\
 | =========                 |                                                 |
 | \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
-|  \\    /   O peration     | Version:  dev                                   |
+|  \\    /   O peration     | Version:  1.6                                   |
 |   \\  /    A nd           | Web:      http://www.OpenFOAM.org               |
 |    \\/     M anipulation  |                                                 |
 \*---------------------------------------------------------------------------*/
diff --git a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/rightSolid/changeDictionaryDict b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/rightSolid/changeDictionaryDict
index fa811e5fe2839549848ba99198e2722325116af3..7e1adc24b3cbe56cb8ee32acec7530b08a38633f 100644
--- a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/rightSolid/changeDictionaryDict
+++ b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/rightSolid/changeDictionaryDict
@@ -1,7 +1,7 @@
 /*--------------------------------*- C++ -*----------------------------------*\
 | =========                 |                                                 |
 | \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
-|  \\    /   O peration     | Version:  dev                                   |
+|  \\    /   O peration     | Version:  1.6                                   |
 |   \\  /    A nd           | Web:      http://www.OpenFOAM.org               |
 |    \\/     M anipulation  |                                                 |
 \*---------------------------------------------------------------------------*/
diff --git a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/rightSolid/fvSchemes b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/rightSolid/fvSchemes
index 8dc070f0eb0e09995c69cd12d99db88f1a80969d..74053b0ab3ded29a9bb6536d918e55e092273405 100644
--- a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/rightSolid/fvSchemes
+++ b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/rightSolid/fvSchemes
@@ -1,7 +1,7 @@
 /*--------------------------------*- C++ -*----------------------------------*\
 | =========                 |                                                 |
 | \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
-|  \\    /   O peration     | Version:  dev                                   |
+|  \\    /   O peration     | Version:  1.6                                   |
 |   \\  /    A nd           | Web:      http://www.OpenFOAM.org               |
 |    \\/     M anipulation  |                                                 |
 \*---------------------------------------------------------------------------*/
diff --git a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/rightSolid/fvSolution b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/rightSolid/fvSolution
index 0396116914478adfd7b2dd998fc93d22ea44e101..19370a0e39c4b42a7a58941a05170e9a33a37b4f 100644
--- a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/rightSolid/fvSolution
+++ b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/rightSolid/fvSolution
@@ -1,7 +1,7 @@
 /*--------------------------------*- C++ -*----------------------------------*\
 | =========                 |                                                 |
 | \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
-|  \\    /   O peration     | Version:  dev                                   |
+|  \\    /   O peration     | Version:  1.6                                   |
 |   \\  /    A nd           | Web:      http://www.OpenFOAM.org               |
 |    \\/     M anipulation  |                                                 |
 \*---------------------------------------------------------------------------*/
diff --git a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/topAir/changeDictionaryDict b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/topAir/changeDictionaryDict
index 46dada5c638f076f6c6958be5de74a68813c3b81..6e9192301de24ef41cc000f14ef9ab40bc7a659f 100644
--- a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/topAir/changeDictionaryDict
+++ b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/topAir/changeDictionaryDict
@@ -1,7 +1,7 @@
 /*--------------------------------*- C++ -*----------------------------------*\
 | =========                 |                                                 |
 | \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
-|  \\    /   O peration     | Version:  dev                                   |
+|  \\    /   O peration     | Version:  1.6                                   |
 |   \\  /    A nd           | Web:      http://www.OpenFOAM.org               |
 |    \\/     M anipulation  |                                                 |
 \*---------------------------------------------------------------------------*/
diff --git a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/topAir/fvSchemes b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/topAir/fvSchemes
index 33f61814eb8a25c4e76871ec9a335355b7d4d601..cedcc3c61167fc381f40b263c8743d9cc76629c6 100644
--- a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/topAir/fvSchemes
+++ b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/topAir/fvSchemes
@@ -1,7 +1,7 @@
 /*--------------------------------*- C++ -*----------------------------------*\
 | =========                 |                                                 |
 | \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
-|  \\    /   O peration     | Version:  dev                                   |
+|  \\    /   O peration     | Version:  1.6                                   |
 |   \\  /    A nd           | Web:      http://www.OpenFOAM.org               |
 |    \\/     M anipulation  |                                                 |
 \*---------------------------------------------------------------------------*/
diff --git a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/topAir/fvSolution b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/topAir/fvSolution
index 51338611052461f9733f4baa891f07d6b1abb822..27f5cfb1dd778872ef6c12a8acdda71bfa29a298 100644
--- a/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/topAir/fvSolution
+++ b/tutorials/heatTransfer/chtMultiRegionFoam/multiRegionHeater/system/topAir/fvSolution
@@ -1,7 +1,7 @@
 /*--------------------------------*- C++ -*----------------------------------*\
 | =========                 |                                                 |
 | \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
-|  \\    /   O peration     | Version:  dev                                   |
+|  \\    /   O peration     | Version:  1.6                                   |
 |   \\  /    A nd           | Web:      http://www.OpenFOAM.org               |
 |    \\/     M anipulation  |                                                 |
 \*---------------------------------------------------------------------------*/
diff --git a/tutorials/multiphase/settlingFoam/ras/dahl/0/p b/tutorials/multiphase/settlingFoam/ras/dahl/0/pmh
similarity index 98%
rename from tutorials/multiphase/settlingFoam/ras/dahl/0/p
rename to tutorials/multiphase/settlingFoam/ras/dahl/0/pmh
index fa58407df2d464ea7f39995138d1616560260221..a2a965130f57a71e8bc7cc3d8126c8fdedfe7143 100644
--- a/tutorials/multiphase/settlingFoam/ras/dahl/0/p
+++ b/tutorials/multiphase/settlingFoam/ras/dahl/0/pmh
@@ -10,7 +10,7 @@ FoamFile
     version     2.0;
     format      ascii;
     class       volScalarField;
-    object      p;
+    object      pmh;
 }
 // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
 
diff --git a/tutorials/multiphase/settlingFoam/ras/dahl/constant/polyMesh/boundary b/tutorials/multiphase/settlingFoam/ras/dahl/constant/polyMesh/boundary
index 03af5cc61a1de4597684a0db0b3f36286752b4b8..7970a504ca025ac502831a1590545ee3176c5002 100644
--- a/tutorials/multiphase/settlingFoam/ras/dahl/constant/polyMesh/boundary
+++ b/tutorials/multiphase/settlingFoam/ras/dahl/constant/polyMesh/boundary
@@ -1,7 +1,7 @@
 /*--------------------------------*- C++ -*----------------------------------*\
 | =========                 |                                                 |
 | \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox           |
-|  \\    /   O peration     | Version:  1.6.x                                 |
+|  \\    /   O peration     | Version:  dev                                   |
 |   \\  /    A nd           | Web:      www.OpenFOAM.org                      |
 |    \\/     M anipulation  |                                                 |
 \*---------------------------------------------------------------------------*/
diff --git a/tutorials/multiphase/settlingFoam/ras/dahl/system/fvSchemes b/tutorials/multiphase/settlingFoam/ras/dahl/system/fvSchemes
index 3802ef8dca8e141c827904721aebf6b4a02450c1..e07687013595e958db395a6ee3fd431eb722fb76 100644
--- a/tutorials/multiphase/settlingFoam/ras/dahl/system/fvSchemes
+++ b/tutorials/multiphase/settlingFoam/ras/dahl/system/fvSchemes
@@ -39,7 +39,7 @@ laplacianSchemes
 {
     default         none;
     laplacian(muEff,U) Gauss linear corrected;
-    laplacian((rho*(1|A(U))),p) Gauss linear corrected;
+    laplacian((rho*(1|A(U))),pmh) Gauss linear corrected;
     laplacian(DkEff,k) Gauss linear corrected;
     laplacian(DepsilonEff,epsilon) Gauss linear corrected;
     laplacian(mut,Alpha) Gauss linear corrected;
@@ -58,7 +58,7 @@ snGradSchemes
 fluxRequired
 {
     default         no;
-    p               ;
+    pmh             ;
 }
 
 
diff --git a/tutorials/multiphase/settlingFoam/ras/dahl/system/fvSolution b/tutorials/multiphase/settlingFoam/ras/dahl/system/fvSolution
index 148cdcddc5c7ec956d8b96cf581f1b4743a3de8f..4f69db6bc0222313e0b2244bbc3525f9b7ba73e7 100644
--- a/tutorials/multiphase/settlingFoam/ras/dahl/system/fvSolution
+++ b/tutorials/multiphase/settlingFoam/ras/dahl/system/fvSolution
@@ -17,7 +17,7 @@ FoamFile
 
 solvers
 {
-    p
+    pmh
     {
         solver          PCG;
         preconditioner  DIC;
diff --git a/tutorials/multiphase/settlingFoam/ras/tank3D/0/U b/tutorials/multiphase/settlingFoam/ras/tank3D/0/U
index 34520705ad68eaa7d211532d7f55e45c023cad50..bac98acc6cf42017b1c0653f92effee12092e5ec 100644
--- a/tutorials/multiphase/settlingFoam/ras/tank3D/0/U
+++ b/tutorials/multiphase/settlingFoam/ras/tank3D/0/U
@@ -57,7 +57,8 @@ boundaryField
 
     WALL6
     {
-        type            fixedValue;
+        type            translatingWallVelocity;
+        U               (-0.003 0 0);
         value           uniform (-0.003 0 0);
     }
 
diff --git a/tutorials/multiphase/settlingFoam/ras/tank3D/0/p b/tutorials/multiphase/settlingFoam/ras/tank3D/0/pmh
similarity index 86%
rename from tutorials/multiphase/settlingFoam/ras/tank3D/0/p
rename to tutorials/multiphase/settlingFoam/ras/tank3D/0/pmh
index 0a6116408579f824f142ff327bb042244d19b084..fafd5b9bb17ae18c697ad721c315d8d96f7b9246 100644
--- a/tutorials/multiphase/settlingFoam/ras/tank3D/0/p
+++ b/tutorials/multiphase/settlingFoam/ras/tank3D/0/pmh
@@ -10,7 +10,7 @@ FoamFile
     version     2.0;
     format      ascii;
     class       volScalarField;
-    object      p;
+    object      pmh;
 }
 // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
 
@@ -28,27 +28,32 @@ boundaryField
 
     INLE1
     {
-        type            zeroGradient;
+        type            buoyantPressure;
+        value           uniform 0;
     }
 
     OUTL9
     {
-        type            zeroGradient;
+        type            buoyantPressure;
+        value           uniform 0;
     }
 
     OUTL10
     {
-        type            zeroGradient;
+        type            buoyantPressure;
+        value           uniform 0;
     }
 
     OUTL11
     {
-        type            zeroGradient;
+        type            buoyantPressure;
+        value           uniform 0;
     }
 
     OUTL12
     {
-        type            zeroGradient;
+        type            buoyantPressure;
+        value           uniform 0;
     }
 
     WALL6
diff --git a/tutorials/multiphase/settlingFoam/ras/tank3D/Allclean b/tutorials/multiphase/settlingFoam/ras/tank3D/Allclean
index 35e38c65c54b6620f679d4494c76cc03f97cdd57..f73c44df8a80af20311035b269db90ae9d88b7ea 100755
--- a/tutorials/multiphase/settlingFoam/ras/tank3D/Allclean
+++ b/tutorials/multiphase/settlingFoam/ras/tank3D/Allclean
@@ -3,4 +3,4 @@
 # Clean time folders only
 
 rm -rf *[1-9]*
-rm -f log.* 2>/dev/null
+rm log.*
diff --git a/tutorials/multiphase/settlingFoam/ras/tank3D/system/controlDict b/tutorials/multiphase/settlingFoam/ras/tank3D/system/controlDict
index cd4042ef6372584dc648b98fcb6e23fe2d936613..b6d0e5c258d1a5c48d72143679dc5da929ad9d4a 100644
--- a/tutorials/multiphase/settlingFoam/ras/tank3D/system/controlDict
+++ b/tutorials/multiphase/settlingFoam/ras/tank3D/system/controlDict
@@ -17,7 +17,7 @@ FoamFile
 
 application     settlingFoam;
 
-startFrom       startTime;
+startFrom       latestTime;
 
 startTime       0;
 
diff --git a/tutorials/multiphase/settlingFoam/ras/tank3D/system/fvSchemes b/tutorials/multiphase/settlingFoam/ras/tank3D/system/fvSchemes
index 3802ef8dca8e141c827904721aebf6b4a02450c1..e07687013595e958db395a6ee3fd431eb722fb76 100644
--- a/tutorials/multiphase/settlingFoam/ras/tank3D/system/fvSchemes
+++ b/tutorials/multiphase/settlingFoam/ras/tank3D/system/fvSchemes
@@ -39,7 +39,7 @@ laplacianSchemes
 {
     default         none;
     laplacian(muEff,U) Gauss linear corrected;
-    laplacian((rho*(1|A(U))),p) Gauss linear corrected;
+    laplacian((rho*(1|A(U))),pmh) Gauss linear corrected;
     laplacian(DkEff,k) Gauss linear corrected;
     laplacian(DepsilonEff,epsilon) Gauss linear corrected;
     laplacian(mut,Alpha) Gauss linear corrected;
@@ -58,7 +58,7 @@ snGradSchemes
 fluxRequired
 {
     default         no;
-    p               ;
+    pmh             ;
 }
 
 
diff --git a/tutorials/multiphase/settlingFoam/ras/tank3D/system/fvSolution b/tutorials/multiphase/settlingFoam/ras/tank3D/system/fvSolution
index 148cdcddc5c7ec956d8b96cf581f1b4743a3de8f..ac27adffb4ca8ad520a8a7db6ac53cb3b6248694 100644
--- a/tutorials/multiphase/settlingFoam/ras/tank3D/system/fvSolution
+++ b/tutorials/multiphase/settlingFoam/ras/tank3D/system/fvSolution
@@ -17,7 +17,7 @@ FoamFile
 
 solvers
 {
-    p
+    pmh
     {
         solver          PCG;
         preconditioner  DIC;
@@ -68,9 +68,17 @@ solvers
 
 PISO
 {
-    nCorrectors     2;
+    momentumPredictor yes;
+    nOuterCorrectors  1;
+    nCorrectors       2;
     nNonOrthogonalCorrectors 0;
 }
 
+relaxationFactors
+{
+    U               1;
+    k               1;
+    epsilon         1;
+}
 
 // ************************************************************************* //
diff --git a/src/finiteVolume/fields/fvPatchFields/derived/buoyantPressure/buoyantPressureFvPatchScalarField.C b/src/finiteVolume/fields/fvPatchFields/derived/buoyantPressure/buoyantPressureFvPatchScalarField.C
index a6ae6f1ee6c79cad14a5cd22cbeeb7948ebea7b1..82604d781d6e5d12a15af86beca4cfc67759d8b1 100644
--- a/src/finiteVolume/fields/fvPatchFields/derived/buoyantPressure/buoyantPressureFvPatchScalarField.C
+++ b/src/finiteVolume/fields/fvPatchFields/derived/buoyantPressure/buoyantPressureFvPatchScalarField.C
@@ -117,10 +117,14 @@ void buoyantPressureFvPatchScalarField::updateCoeffs()
     const fvPatchField<scalar>& rho =
         patch().lookupPatchField<volScalarField, scalar>(rhoName_);
 
     // If the variable name is "pd" assume it is p - rho*g.h
     // and set the gradient appropriately.
     // Otherwise assume the variable is the static pressure.
-    if (dimensionedInternalField().name() == "pd")
+    if
+    (
+        dimensionedInternalField().name() == "pmh"
+     || dimensionedInternalField().name() == "pd"
+    )
     {
         gradient() = -rho.snGrad()*(g.value() & patch().Cf());
     }
@@ -117,10 +117,14 @@ void buoyantPressureFvPatchScalarField::updateCoeffs()
         patch().lookupPatchField<volScalarField, scalar>(rhoName_);
 
-    // If the variable name is "pd" assume it is p - rho*g.h
+    // If the variable name is "pmh" or "pd" assume it is p - rho*g.h
     // and set the gradient appropriately.
     // Otherwise assume the variable is the static pressure.